========================
Application Notes
========================

This folder is a collection of some example code snippets and discussions applied to various situations


.. toctree::
   :maxdepth: 1

   strain
